environment/debug_environment library

Classes

DebugEnvironment
A backend the app can be switched to from the log page.
DebugEnvironments
Keeps the selected environment and remembers it between app starts.