name property
Name shown in the switcher. Environments with the same name on different Dio instances are switched together.
Implementation
final String name;
Name shown in the switcher. Environments with the same name on different Dio instances are switched together.
final String name;