environments property
Backends this Dio can be switched to from the log page. When empty, the
list from DioDebugLogger.setEnvironments is used.
Implementation
final List<DebugEnvironment> environments;
Backends this Dio can be switched to from the log page. When empty, the
list from DioDebugLogger.setEnvironments is used.
final List<DebugEnvironment> environments;