redactSensitiveHeaders property
Whether secrets (passwords, tokens, keys…) are masked in the console, in headers, bodies and URLs.
Implementation
final bool redactSensitiveHeaders;
Whether secrets (passwords, tokens, keys…) are masked in the console, in headers, bodies and URLs.
final bool redactSensitiveHeaders;