NetworkLogger class
Old name of DioDebugLogger, kept for backward compatibility.
- Annotations
-
- @Deprecated('Use DioDebugLogger instead. Will be removed in 1.0.0.')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isOpen → bool
-
no setter
-
isOpenNotifier
→ ValueNotifier<
bool> -
no setter
-
getter/setter pair
- observer → DebugNavigatorObserver
-
no setter
- retryClientBuilder ↔ Dio Function()?
-
getter/setter pair
- storage → DebugStorage
-
no setter
Static Methods
-
close(
[BuildContext? context]) → void -
configure(
{int? maxRequests}) → void -
createRetryClient(
) → Dio -
interceptor(
{bool? printToConsole, bool redactSensitiveHeaders = true}) → Interceptor -
open(
[BuildContext? context]) → Future< void> -
overlayBuilder(
{bool enabled = kDebugMode, Color? backgroundColor, Color? foregroundColor, IconData icon = Icons.bug_report_rounded, double buttonSize = 56, bool showBadge = true, Alignment initialAlignment = Alignment.centerLeft, bool snapToEdge = true}) → TransitionBuilder