CopyHelper class
Converts a request to text in various formats.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateCurlCommand(
DebugModel model, {bool redact = false}) → String -
generateJsonRequest(
DebugModel model, {bool redact = false}) → String -
generatePostmanJson(
DebugModel model, {bool redact = false}) → String -
generateResponseBody(
DebugModel model, {bool redact = true}) → String - Response body only.
-
generateSummary(
DebugModel model, {bool redact = true}) → String - Readable summary of the request and response (for bug reports).